<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_blog_posts extends Widget_Base {
	public function get_name() {
		return 'asw-blog-posts';
	}
	public function get_title() {
		return __( 'Blog posts', 'wythe-elements' );
	}
	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-post-list';
	}
	/**
	 * Retrieve the list of categories the accordion widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'asw-elements' ];
	}
	protected function _register_controls() {

		$this->start_controls_section(
			'section_blog_post',
			[
				'label' => esc_html__( 'Blog Posts', 'wythe-elements' ),
			]
		);
		
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Number of Items', 'wythe-elements' ),
				'description' => __('Enter items count per view', 'wythe-elements'),
				'type' => Controls_Manager::TEXT,
				'default' => '4',
			]
		);
		$this->add_control(
			'cat_slug',
			[
				'label' => __( 'Categories to display', 'wythe-elements' ),
				'description' => __('Enter category to display items. Separate categories by commas.', 'wythe-elements'),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->add_control(
			'tag_slug',
			[
				'label' => __( 'Tags to display', 'wythe-elements' ),
				'description' => __('Enter tag to display items. Separate tags by commas.', 'wythe-elements'),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->add_control(
			'columns_count',
			[
				'label' => __( 'Items per row', 'wythe-elements' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'cols-2' => __( 'Two', 'wythe-elements' ),
					'cols-3' => __( 'Three', 'wythe-elements' ),
					'cols-4' => __( 'Four', 'wythe-elements' ),
					'cols-5' => __( 'Five', 'wythe-elements' ),
				],
				'default' => 'cols-4',
			]
		);
		$this->add_control(
			'order',
			[
				'label' => __( 'Posts Order', 'wythe-elements' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'DESC' => [
						'title' => __( 'descending', 'wythe-elements' ),
						'icon' => 'fa fa-sort-amount-desc',
					],
					'ASC' => [
						'title' => __( 'ascending', 'wythe-elements' ),
						'icon' => 'fa fa-sort-amount-asc',
					],
				],
				'default' => 'DESC',
			]
		);
		
		$this->end_controls_section();
		$this->start_controls_section(
			'section_blog_style',
			[
				'label' => __( 'Blog style', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'blog_style',
			[
				'label' => __( 'Blog style', 'wythe-elements' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'standard' => __( 'Standard', 'wythe-elements' ),
					'overlay' => __( 'Overlay', 'wythe-elements' ),
				],
				'default' => 'standard',
			]
		);
		$this->add_control(
			'blog_overlay_color',
			[
				'label' => __( 'Overlay Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .blog-item.blog-overlay .overlay-img' => 'background-color: {{VALUE}};'
				],
			]
		);
		$this->end_controls_section();
	}
	protected function render( $instance = [] ) {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$post_count = ! empty( $settings['posts_per_page'] ) ? (int)$settings['posts_per_page'] : 7;
		$order = ! empty( $settings['order'] ) ? $settings['order'] : 'DESC';
		$blog_style = ! empty( $settings['blog_style'] ) ? $settings['blog_style'] : 'standard';
		$blog_style = 'blog-'.$blog_style;
		$columns_count = ! empty( $settings['columns_count'] ) ? $settings['columns_count'] : 'cols-4';
		$cat_slug = !empty( $settings['cat_slug'] ) ? $settings['cat_slug'] : '';
		$tag_slug = !empty( $settings['tag_slug'] ) ? $settings['tag_slug'] : '';

		global $paged;
		global $post;
		if ( is_front_page() ) {
		    $paged = (get_query_var('page')) ? get_query_var('page') : 1;
		} else {
		    $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
		}

		$args = array(
		    'post_type' => 'post',
		    'posts_per_page' => $post_count,
		    'paged' => $paged,
		    'order'          => $order,
		    'orderby'        => 'date',
		    'post_status'    => 'publish'
		);
		if($cat_slug != ''){
			// string to array
			$cat_slug = trim($cat_slug);
			$arr = explode(',', $cat_slug);
			$args['tax_query'][] = array(
				'taxonomy'  => 'category',
				'field'   => 'name',
				'terms'   => $arr
			);
		}
		if($tag_slug != ''){
			// string to array
			$tag_slug = trim($tag_slug);
			$arr = explode(',', $tag_slug);
			$args['tax_query'][] = array(
				'taxonomy'  => 'post_tag',
				'field'   => 'name',
				'terms'   => $arr
			);
		}
		query_posts( $args );
		$out = '';

		if( have_posts() ) {
			$out .= '<div class="blog-grid '.$columns_count.'">';
			while ( have_posts() ) {
				the_post();
				$thumbnail= wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'medium' );
				$out .= '<div class="blog-item '.$blog_style.'" data-scrolled-into-view><!-- start blog post item -->';
					$out .= '<figure class="post-img">';
					if( is_array($thumbnail) && isset($thumbnail[0]) ){ 
						$out .= '<img src="'.$thumbnail[0].'" width="'.$thumbnail[1].'" height="'.$thumbnail[2].'" alt="'.get_the_title().'">';
					}
					$out .= '<div class="overlay-img"></div></figure>';
					$terms = get_the_category();
					if ( ! empty($terms) ) {
						$terms_out = array();
						$out .= '<div class="meta-categories">';
						$i = 1;
						foreach ( $terms as $term ){
							$terms_out[] = '<a href="' .get_category_link( $term->term_id ) .'">'.$term->name.'</a>';
							if (++$i == 3) break;
						}
							
						$out .= join( ', ', $terms_out );
						$out .= '</div><!-- post categories -->';
					}
					$out .= '<h3 class="blog-item-title"><a href="'.get_permalink().'">'.get_the_title().'</a></h3>';
					$out .= '<a href="'.get_permalink().'" class="blog-item-more">'.__('Read more', 'wythe-elements').'</a>';
				$out .= '</div><!-- end blog post item -->';
			}

			$out .= '</div>';
			echo $out;
		}

		wp_reset_query();
	}
}
?>