<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Icon List Widget
 */
class Widget_ASW_clients extends Widget_Base {

	/**
	 * Retrieve icon list widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'asw-clients';
	}

	/**
	 * Retrieve icon list widget title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Clients', 'wythe-elements' );
	}

	/**
	 * Retrieve icon list widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-users';
	}

	/**
	 * Retrieve the list of categories the icon list widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'asw-elements' ];
	}

	/**
	 * Register icon list widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'asw_section_clients',
			[
				'label' => __( 'Clients', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'asw_clients_list',
			[
				'label' => '',
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'image' => ['url'=>'http://localhost/wythe/wp-content/uploads/2017/09/client-logo1.png'],
						'link' => ['url'=>'http://google.com'],
					],
					[
						'image' => ['url'=>'http://localhost/wythe/wp-content/uploads/2017/09/client-logo2.png'],
						'link' => ['url'=>'http://google.com'],
					],
				],
				'fields' => [
					
					[
						'name' => 'image',
						'label' => __( 'Choose Image', 'wythe-elements' ),
						'type' => Controls_Manager::MEDIA,
						'default' => [
							'url' => Utils::get_placeholder_image_src(),
						],
					],
					[
						'name' => 'link',
						'label' => __( 'Link', 'wythe-elements' ),
						'type' => Controls_Manager::URL,
						'label_block' => true,
						'placeholder' => 'http://your-link.com',
					],
				],
				'title_field' => '<img src="{{ image.url }}" alt=""/>',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render icon list widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		?>
		<ul class="clients-logo">
			<?php foreach ( $settings['asw_clients_list'] as $index => $item ) : ?>
				<li>
					<?php
					$img = !empty($item['image']['url']) ? '<img src="'.esc_url($item['image']['url']).'" alt="">' : '<img src="'.Utils::get_placeholder_image_src().'" alt="">';
					if ( ! empty( $item['link']['url'] ) ) {
						$link_key = 'link_' . $index;

						$this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

						if ( $item['link']['is_external'] ) {
							$this->add_render_attribute( $link_key, 'target', '_blank' );
						}

						if ( $item['link']['nofollow'] ) {
							$this->add_render_attribute( $link_key, 'rel', 'nofollow' );
						}
						echo '<a ' . $this->get_render_attribute_string( $link_key ) . '>'.$img.'</a>';
					} else {
						echo $img;
					} ?>
				</li>
				<?php
			endforeach;
			?>
		</ul>
		<?php
	}

	/**
	 * Render icon list widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<ul class="clients-logo">
			<#
			if ( settings.asw_clients_list ) {
				_.each( settings.asw_clients_list, function( item ) { #>
					<li>
						<# if ( item.link && item.link.url ) { #>
							<a href="{{ item.link.url }}"><img src="{{ item.image.url }}" alt=""></a>
						<# } else { #>
							<img src="{{ item.image.url }}" alt="">
						<# } #>
					</li>
				<#
				} );
			} #>
		</ul>
		<?php
	}
}
