<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_contact_block extends Widget_Base {
	public function get_name() {
		return 'asw-contact-block';
	}

	public function get_title() {
		return __( 'Contact block', 'wythe-elements' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'fa fa-map-o';
	}

	public function get_categories() {
		return [ 'asw-elements' ];
	}

    /*public function get_script_depends() {
		return [ 'gmaps.api' ];
	}*/

	protected function _register_controls() {

		$this->start_controls_section(
			'section_google_map',
			[
				'label' => esc_html__( 'Google map', 'wythe-elements' ),
			]
		);
		
		$this->add_control(
			'address',
			[
				'label' => __( 'Address', 'wythe-elements' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'West Village, NY, USA',
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Location image', 'wythe-elements' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => get_template_directory_uri().'/images/map-marker.png',
				],
			]
		);
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_contact_form',
			[
				'label' => esc_html__( 'Contact form', 'wythe-elements' ),
			]
		); 

		if(class_exists('WPCF7')){
			$args = array('post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1);
			$rs = array();
			if( $data = get_posts($args)){
			    foreach($data as $key){
			        $rs[$key->ID] = $key->post_title;
			    }
			}else{
			    $rs[0] = esc_html__('No Contact Form found', 'wythe-elements');
			}
			wp_reset_postdata();
		
			$this->add_control(
				'select_cf7_form',
				[
					'label' => __( 'Contact form', 'wythe-elements' ),
					'type' => Controls_Manager::SELECT,
					'default' => '',
					'options' => $rs,
					'description' => esc_html__('Create your form in contact from 7 plugin, before select it.', 'wythe-elements'),
				]
			);
		} else {
			$this->add_control(
				'none_cf7_form',
				[
					'label' => esc_html__('Contact from 7 plugin is required!', 'wythe-elements'),
					'type' => Controls_Manager::HEADING,
				]
			);
		}
		$this->end_controls_section();

		$this->start_controls_section(
			'contact_block_style',
			[
				'label' => __( 'Form style', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'contact_block_color',
			[
				'label' => __( 'Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpcf7 input[type="text"], {{WRAPPER}} .wpcf7 input[type="email"], {{WRAPPER}} .wpcf7 textarea, {{WRAPPER}} .wpcf7 input::-webkit-input-placeholder, {{WRAPPER}} .wpcf7 textarea::-webkit-input-placeholder' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'contact_block_border_color',
			[
				'label' => __( 'Border Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpcf7 input[type="text"], {{WRAPPER}} .wpcf7 input[type="email"], {{WRAPPER}} .wpcf7 textarea' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'contact_block_button_style',
			[
				'label' => __( 'Button style', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .wpcf7 .button',
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Button Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .wpcf7 .button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label' => __( 'Button Background Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpcf7 .button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'button_text_color_hover',
			[
				'label' => __( 'Button Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .wpcf7 .button:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_color_hover',
			[
				'label' => __( 'Button Background Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpcf7 .button:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();

	}
	protected function render() {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$address = ! empty( $settings['address'] ) ? $settings['address'] : 'West Village, NY, USA';
		$image = !empty($settings['image']['url']) ? $settings['image']['url'] : get_template_directory_uri().'/images/map-marker.png';
		if(class_exists('WPCF7')){
			$args = array('post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1);
			$rs = array();
			if( $data = get_posts($args)){
			    foreach($data as $key){
			        $rs[$key->ID] = $key->post_title;
			    }
			}else{
			    $rs[0] = esc_html__('No Contact Form found', 'wythe-elements');
			}
			wp_reset_postdata();
			$form_id = ! empty( $settings['select_cf7_form'] ) ? $settings['select_cf7_form'] : '';
			if( isset( $rs[$form_id] ) ){
				$form = '[contact-form-7 id="'.$form_id.'" title="'.$rs[$form_id].'"]';
			} else {
				$form = esc_html__('Contact form not found!', 'wythe-elements');
			}
			
		} else {
			$form = esc_html__('Contact from 7 plugin is required to have form.', 'wythe-elements');
		}
		?>
		<div class="map-form-block dtable">
			<div class="map-block dtcell">
				<div id="map"></div><!-- contact map -->
			</div>
			<div class="form-block dtcell">
				<?php echo do_shortcode($form); ?>
			</div><!-- end div .form-block -->
		</div><!-- end div .map-form-block -->
		<script type="text/javascript">
		var map;
			function initMap() {
			  var styles = [{"featureType":"all","elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#000000"},{"lightness":40}]},{"featureType":"all","elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#000000"},{"lightness":16}]},{"featureType":"all","elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#000000"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#000000"},{"lightness":17},{"weight":1.2}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":20}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":21}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#000000"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#000000"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":16}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":19}]},{"featureType":"water","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":17}]}];
			  map = new google.maps.Map(document.getElementById('map'), {
			    center: {
			    	lat: -34.397, 
			    	lng: 150.644
			    },
			    zoom: 15,
			    navigationControl:!1,
			    mapTypeControl:!1,
			    scaleControl:!1,
			    streetViewControl:!1,
			  });
			  map.setOptions({styles: styles});
				var address = '<?php echo $address; ?>';
				var geocoder = new google.maps.Geocoder();
				var image = '<?php echo esc_url($image); ?>';
				geocoder.geocode({
				  'address': address
				}, 
				function(results, status) {
				  if(status == google.maps.GeocoderStatus.OK) {
				     new google.maps.Marker({
				        position: results[0].geometry.location,
				        map: map,
				        icon: image
				     });
				     map.setCenter(results[0].geometry.location);
				  }
				});
			}
    	</script>
    	<script async defer src="https://maps.googleapis.com/maps/api/js?key=AIzaSyBfbDATAIBSQEUY0YzOEjzcB8A1W2FNKSQ&libraries=places,geometry&callback=initMap&v=3.26"></script>
		<?php
	}
}
?>