<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_cta_block extends Widget_Base {
	public function get_name() {
		return 'asw-cta-block';
	}
	public function get_title() {
		return __( 'Call to Action', 'wythe-elements' );
	}
	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'fa fa-hand-pointer-o';
	}
	public function get_categories() {
		return [ 'asw-elements' ];
	}
	protected function _register_controls() {
		$this->start_controls_section(
			'section_cta_block',
			[
				'label' => esc_html__( 'Call to Action', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'asw_text',
			[
				'label' => __( 'Call to Action Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your title', 'wythe-elements' ),
				'default' => 'We\'re an independent creative agency, that builds successful brands.',
			]
		);

		$this->add_control(
			'asw_button_text',
			[
				'label' => __( 'Button Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Get started', 'wythe-elements'),
				'title' => __( 'Enter your button text', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'asw_link',
			[
				'label' => __( 'Button Link', 'wythe-elements' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://google.com',
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_asw_cta_style',
			[
				'label' => __( 'Call to Action', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'asw_text_color',
			[
				'label' => __( 'Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .cta-text',
			]
		);
		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Button Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .cta-button .button span' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_border_color',
			[
				'label' => __( 'Button Border Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-button .button' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label' => __( 'Button Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-button .button:hover span' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_hover_color',
			[
				'label' => __( 'Button Background Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .cta-button .button:hover:before' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .cta-button .button:hover' => 'border-color: {{VALUE}};'
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$asw_title = ! empty( $settings['asw_title'] ) ? $settings['asw_title'] : 'Title';
		$asw_subtitle = ! empty( $settings['asw_subtitle'] ) ? $settings['asw_subtitle'] : 'Subtitle';
		$asw_text = ! empty( $settings['asw_text'] ) ? $settings['asw_text'] : '';
		$asw_button_text = ! empty( $settings['asw_button_text'] ) ? $settings['asw_button_text'] : '';
		$asw_link = ! empty( $settings['asw_link']['url'] ) ? $settings['asw_link']['url'] : '';
		$asw_icon = ! empty( $settings['asw_icon'] ) ? $settings['asw_icon'] : 'fa-play';
		$button = '';
		if ( ! empty( $settings['asw_link']['url'] ) ) {
			$this->add_render_attribute( 'url', 'href', $settings['asw_link']['url'] );

			if ( $settings['asw_link']['is_external'] ) {
				$this->add_render_attribute( 'url', 'target', '_blank' );
			}

			if ( ! empty( $settings['asw_link']['nofollow'] ) ) {
				$this->add_render_attribute( 'url', 'rel', 'nofollow' );
			}

			$button = sprintf( '<a %1$s class="button"><span>%2$s</span></a>', $this->get_render_attribute_string( 'url' ), esc_html($asw_button_text) );
		}

		?>
		<div class="cta-block">
			<div class="cta-text"><?php echo esc_html($asw_text); ?></div>
			<div class="cta-button"><?php echo $button; ?></div>
		</div>
		<?php
	}
	protected function content_template() {}
}
?>