<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_dropcap_intro extends Widget_Base {
	public function get_name() {
		return 'asw-dropcap-intro';
	}
	public function get_title() {
		return __( 'Dropcap Intro', 'wythe-elements' );
	}
	public function get_icon() {
		return 'fa fa-text-width';
	}
	public function get_categories() {
		return [ 'asw-elements' ];
	}
	protected function _register_controls() {
		$this->start_controls_section(
			'section_asw_intro',
			[
				'label' => esc_html__( 'Intro', 'wythe-elements' ),
			]
		);
		
		$this->add_control(
			'asw_dropcap',
			[
				'label' => __( 'Dropcap letter', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Your letter', 'wythe-elements'),
				'title' => __( 'Enter your dropcap letter for intro block.', 'wythe-elements' ),
			]
		);
		$this->add_control(
			'asw_text',
			[
				'label' => __( 'Intro Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your text', 'wythe-elements' ),
				'default' => 'Aenean sollicitudin, loreuis bibendum auctor elit con sequat ipsum, nec sagittis sem nibh id elit. Dui eddio sit amet nibh vulputate curs sit ametaw mauris. Mor accumsan ipsum velit.',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_asw_dropcap_style',
			[
				'label' => __( 'Dropcap', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'asw_dropcap_color',
			[
				'label' => __( 'Dropcap Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .description .dropcap' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'dropcap_typography',
				'selector' => '{{WRAPPER}} .description .dropcap',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_asw_introtext_style',
			[
				'label' => __( 'Intro text', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'intro_text_color',
			[
				'label' => __( 'Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .description .text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'intro_typography',
				'selector' => '{{WRAPPER}} .description .text',
			]
		);

		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$dropcap = ! empty( $settings['asw_dropcap'] ) ? $settings['asw_dropcap'] : '';
		$asw_text = ! empty( $settings['asw_text'] ) ? $settings['asw_text'] : '';
		?>
		<div class="description dtable">
			<?php if($dropcap !== ''){ ?><div class="dropcap dtcell"><?php echo esc_html($dropcap); ?></div><?php } ?>
			<?php if($asw_text !== ''){ ?><div class="text dtcell"><?php echo esc_html($asw_text); ?></div><?php } ?>
		</div>
		<?php
	}
	protected function content_template() {}
}
?>