<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_fonts_block extends Widget_Base {
	public function get_name() {
		return 'asw-fonts-block';
	}
	public function get_title() {
		return __( 'Fonts preview', 'wythe-elements' );
	}
	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'fa fa-font';
	}
	public function get_categories() {
		return [ 'asw-elements' ];
	}
	protected function _register_controls() {
		$this->start_controls_section(
			'asw_fonts_preview',
			[
				'label' => __( 'Font preview block', 'wythe-elements' ),
			]
		);
		$this->add_control(
			'font_name',
			[
				'label' => __( 'Enter font name', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Font family'
			]
		);
		$this->add_control(
			'example_text',
			[
				'label' => __( 'Enter example text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Body text example',
			]
		);
		$this->add_control(
			'main_color',
			[
				'label' => __( 'Big letter color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .font-preview-block .main-letter' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'font_family',
			[
				'label' => __( 'Font-family', 'wythe-elements' ),
				'type' => Controls_Manager::FONT,
				'default' => 'Playfair Display',
				'selectors' => [
					'{{WRAPPER}} .font-preview-block' => 'font-family: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'font_size',
			[
				'label' => __( 'Example font size', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 12,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .font-preview-block .example' => 'font-size: {{SIZE}}px;',
				],
			]
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();

		$asw_font = ! empty( $settings['font_name'] ) ? $settings['font_name'] : '';
		$asw_example_text = ! empty( $settings['example_text'] ) ? $settings['example_text'] : '';
		$out = '';
		$out .= '<div class="font-preview-block">
			<div class="main-letter">Aa</div>
			<div class="text-wrap">
				<div class="font-family">'.esc_html($asw_font).'</div>
				<div class="example">'.esc_html($asw_example_text).'</div>
			</div>
		</div>';
		echo $out;
	}
	protected function content_template() {}
}
?>