<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_info_block extends Widget_Base {
	public function get_name() {
		return 'asw-info-block';
	}
	public function get_title() {
		return __( 'Info block', 'wythe-elements' );
	}
	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'fa fa-info';
	}
	public function get_categories() {
		return [ 'asw-elements' ];
	}
	protected function _register_controls() {
		$this->start_controls_section(
			'section_asw_title',
			[
				'label' => esc_html__( 'Info Block', 'wythe-elements' ),
			]
		);
		
		$this->add_control(
			'asw_title',
			[
				'label' => __( 'Title Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Your title', 'wythe-elements'),
				'title' => __( 'Enter your title text', 'wythe-elements' ),
			]
		);
		$this->add_control(
			'asw_subtitle',
			[
				'label' => __( 'Subtitle Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Your subtitle', 'wythe-elements'),
				'title' => __( 'Enter your subtitle text', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'asw_text',
			[
				'label' => __( 'Info Block Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your text', 'wythe-elements' ),
				'default' => 'Aenean sollicitudin, loreuis bibendum auctor elit con sequat ipsum, nec sagittis sem nibh id elit. Dui eddio sit amet nibh vulputate curs sit ametaw mauris. Mor accumsan ipsum velit.',
			]
		);

		$this->add_control(
		'show_button',
			[
				'label' => __( 'Show button', 'wythe-elements' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'false',
				'label_on' => __( 'Show', 'wythe-elements' ),
				'label_off' => __( 'Hide', 'wythe-elements' ),
				'return_value' => 'true',
			]
		);

		$this->add_control(
			'asw_button_text',
			[
				'label' => __( 'Button Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Your button', 'wythe-elements'),
				'title' => __( 'Enter your button text', 'wythe-elements' ),
				'condition' => [
					'show_button' => 'true',
				],
			]
		);

		$this->add_control(
			'asw_link',
			[
				'label' => __( 'Button Link', 'wythe-elements' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://google.com',
				'default' => [
					'url' => '//player.vimeo.com/video/99647025',
				],
				'condition' => [
					'show_button' => 'true',
				],
			]
		);

		$this->add_control(
		'popup_button',
			[
				'label' => __( 'Open in lightbox?', 'wythe-elements' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'false',
				'label_on' => __( 'Yes', 'wythe-elements' ),
				'label_off' => __( 'No', 'wythe-elements' ),
				'return_value' => 'true',
			]
		);

		$this->add_control(
			'asw_icon',
			[
				'label' => __( 'Choose Button Icon', 'wythe-elements' ),
				'type' => Controls_Manager::ICON,
				'default' => 'fa-play',
				'condition' => [
					'show_button' => 'true',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_asw_title_style',
			[
				'label' => __( 'Title', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'asw_title_color',
			[
				'label' => __( 'Title Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .title-block h2' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'asw_subtitle_color',
			[
				'label' => __( 'Subitle Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .title-block .subtitle' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'asw_text_color',
			[
				'label' => __( 'Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .info-block .text' => 'color: {{ VALUE }};',
				],
			]
		);

		$this->add_control(
			'asw_button_color',
			[
				'label' => __( 'Button Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .custom-button' => 'color: {{VALUE}};',
				],
				'condition' => [
					'show_button' => 'true',
				],
			]
		);

		$this->add_control(
			'asw_button_font',
			[
				'label' => __( 'Button Font-family', 'wythe-elements' ),
				'type' => Controls_Manager::FONT,
				'selectors' => [
					'{{WRAPPER}} .custom-button span' => 'font-family: {{VALUE}};',
				],
				'condition' => [
					'show_button' => 'true',
				],
			]
		);

		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$asw_title = ! empty( $settings['asw_title'] ) ? $settings['asw_title'] : '';
		$asw_subtitle = ! empty( $settings['asw_subtitle'] ) ? $settings['asw_subtitle'] : '';
		$asw_text = ! empty( $settings['asw_text'] ) ? $settings['asw_text'] : '';
		$asw_button_text = ! empty( $settings['asw_button_text'] ) ? $settings['asw_button_text'] : '';
		$asw_link = ! empty( $settings['asw_link']['url'] ) ? $settings['asw_link']['url'] : '';
		$asw_icon = ! empty( $settings['asw_icon'] ) ? $settings['asw_icon'] : 'fa-play';
		$popup_button = $settings['popup_button'] == 'true' ? true : false;
		$button = '';
		if ( ! empty( $settings['asw_link']['url'] ) ) {
			$this->add_render_attribute( 'url', 'href', $settings['asw_link']['url'] );

			if ( $settings['asw_link']['is_external'] ) {
				$this->add_render_attribute( 'url', 'target', '_blank' );
			}

			if ( ! empty( $settings['asw_link']['nofollow'] ) ) {
				$this->add_render_attribute( 'url', 'rel', 'nofollow' );
			}

			$data_rel = $popup_button ? 'data-rel="lightcase"' : '';

			$button = sprintf( '<a %1$s class="custom-button fa %3$s" %4$s><span>%2$s</span></a>', $this->get_render_attribute_string( 'url' ), esc_html($asw_button_text), $asw_icon, $data_rel );
		}

		?>
		
		<div class="info-block">
			<?php if( $asw_title != '' || $asw_subtitle != '' ){ ?>
			<div class="title-block"><!-- start title block -->
				<span class="subtitle"><?php echo esc_html($asw_subtitle);?></span>
				<h2><?php echo esc_html($asw_title);?></h2>
			</div>
			<?php } ?>
			<div class="text"><?php echo esc_html($asw_text);?></div>
		</div>
		<?php if( $settings['show_button'] == 'true' ){
			echo $button;
		} ?>
		<?php
	}
	protected function content_template() {}
}
?>