<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_portfolio extends Widget_Base {
	public function get_name() {
		return 'asw-portfolio';
	}

	public function get_title() {
		return __( 'Portfolio', 'wythe-elements' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'fa fa-picture-o';
	}

	/*public function get_script_depends() {
		return [ 'owl.carousel' ];
	}*/

	public function get_categories() {
		return [ 'asw-elements' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_portfolio',
			[
				'label' => esc_html__( 'Portfolio', 'wythe-elements' ),
			]
		);
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Number of Items', 'wythe-elements' ),
				'description' => __('Enter items count per view', 'wythe-elements'),
				'type' => Controls_Manager::TEXT,
				'default' => '7',
			]
		);
		$this->add_control(
			'cat_slug',
			[
				'label' => __( 'Categories to display', 'wythe-elements' ),
				'description' => __('Enter category to display items. Separate categories by commas.', 'wythe-elements'),
				'type' => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->add_control(
			'order',
			[
				'label' => __( 'Items Order', 'wythe-elements' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'DESC' => [
						'title' => __( 'descending', 'wythe-elements' ),
						'icon' => 'fa fa-sort-amount-desc',
					],
					'ASC' => [
						'title' => __( 'ascending', 'wythe-elements' ),
						'icon' => 'fa fa-sort-amount-asc',
					],
				],
				'default' => 'DESC',
			]
		);
		$this->add_control(
			'button_more',
			[
				'label' => __( 'Show More Button', 'wythe-elements' ),
				'type' => Controls_Manager::SWITCHER,
				'label_off' => __( 'Off', 'wythe-elements' ),
				'label_on' => __( 'On', 'wythe-elements' ),
				'default' => 'true',
				'return_value' => 'true'
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_portfolio_style',
			[
				'label' => __( 'Portfolio style', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'portfolio_title_color',
			[
				'label' => __( 'Title Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .portfolio-item-title h3' => 'color: {{VALUE}};'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'portfolio_typography',
				'selector' => '{{WRAPPER}} .portfolio-item-title h3',
			]
		);
	}
	protected function render( ) {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$button_more = ! empty( $settings['button_more'] ) ? (bool)$settings['button_more'] : '';
		$post_count = ! empty( $settings['posts_per_page'] ) ? (int)$settings['posts_per_page'] : 7;
		$order = ! empty( $settings['order'] ) ? $settings['order'] : 'DESC';
		$cat_slug = !empty( $settings['cat_slug'] ) ? $settings['cat_slug'] : '';

		global $paged;
		global $post;
		if ( is_front_page() ) {
		    $paged = (get_query_var('page')) ? get_query_var('page') : 1;
		} else {
		    $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
		}

		$args = array(
		    'post_type' => 'portfolio',
		    'posts_per_page' => $post_count,
		    'paged' => $paged,
		    'order'          => $order,
		    'orderby'        => 'date',
		    'post_status'    => 'publish'
		);
		if($cat_slug != ''){
			// string to array
			$cat_slug = trim($cat_slug);
			$arr = explode(',', $cat_slug);
			$args['tax_query'][] = array(
				'taxonomy'  => 'portfolio_filter',
				'field'   => 'name',
				'terms'   => $arr
			);
		}
		query_posts( $args );
		$out = '';
		if( have_posts() ) {
			$out .= '<div class="row portfolio-container five-per-row">';
			while ( have_posts() ) {
				the_post();
				$item_style = null !== get_post_meta( get_the_ID(), 'asw_portfolio_title_color', true ) ?  get_post_meta( get_the_ID(), 'asw_portfolio_title_color', true ) : '';
				$item_width = null !== get_post_meta( get_the_ID(), 'asw_portfolio_width', true ) ?  get_post_meta( get_the_ID(), 'asw_portfolio_width', true ) : '';
				$portfolio_thumbnail= wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
				$out .= '<div class="portfolio-item '.$item_style.' '.$item_width.'"><!-- start portfolio item -->';
					$out .= '<div class="portfolio-meta"><!-- start portfolio meta -->';
						if(function_exists('getPostLikeLink')) { $out .= getPostLikeLink($post->ID); }
						$out .= '<div class="time">'.get_the_date( 'd.m.Y' ).'</div>';
						$out .= '<a href="'. get_permalink() .'" class="portfolio-item-more"><i class="ion-ios-arrow-right"></i></a>';
					$out .= '</div><!-- end portfolio meta -->';
					$out .= '<header class="portfolio-header"><!-- start portfolio header -->';
						$out .= '<div class="portfolio-item-title">';
							$terms = get_the_terms( $post->ID, 'portfolio_filter' );
							if ( $terms && !is_wp_error( $terms ) ) {
								$terms_out = array();
								$out .= '<div class="meta-categories">';
								foreach ( $terms as $term )
									$terms_out[] = '<a href="' .get_term_link($term->slug, 'portfolio_filter') .'">'.$term->name.'</a>';
								$out.= join( ', ', $terms_out );
								$out .= '</div><!-- portfolio categories -->';
							}
							$out .= '<h3>'. get_the_title() .'</h3> <!-- portfolio title -->';
						$out .= '</div>';
						$out .= '<a href="'. get_permalink() .'" title="'. get_the_title() .'">';
							$out .= '<figure class="portfolio-img"><img class="featured-image" src="'.$portfolio_thumbnail[0].'" width="'.$portfolio_thumbnail[1].'" height="'.$portfolio_thumbnail[2].'" alt="'. get_the_title() .'"/></figure><!-- portfolio featured image -->';
						$out .= '</a>';
					$out .= '</header><!-- end portfolio header -->';
				$out .= '</div><!-- end portfolio item -->';
			}
				if( $button_more ){
					$out .= '<div class="portfolio-item portfolio-more-items" data-scrolled-into-view>';
						$out .= '<a href="#" class="load-more active"><span data-the-end="'.esc_html__('THE END', 'wythe-elements').'">'.esc_html__('MORE', 'wythe-elements').'</span></a><!-- portfolio load-more button -->';
					$out .= '<div style="display:none;">'.get_next_posts_link().'</div>';
					$out .= '</div>';
				}

			$out .= '</div>';
			echo $out;
		}
		wp_reset_query();
	}
}
?>