<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Social Icons Widget
 */
class Widget_ASW_project_info_list extends Widget_Base {

	/**
	 * Retrieve social icons widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'asw-project-info-list';
	}

	/**
	 * Retrieve social icons widget title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Project info', 'wythe-elements' );
	}

	/**
	 * Retrieve social icons widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-list-ul';
	}

	/**
	 * Retrieve the list of categories the social icons widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'asw-elements' ];
	}

	/**
	 * Register social icons widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_project_info',
			[
				'label' => __( 'Project info', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'List Title', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => ''
			]
		);

		$this->add_control(
			'project_info_list',
			[
				'label' => __( 'Info list', 'wythe-elements' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'icon' => '',
						'item' => 'Role',
						'value' => 'Art Director'
					],
					[
						'icon' => '',
						'item' => 'Agency',
						'value' => 'Freelance'
					],
					[
						'icon' => '',
						'item' => 'Photos',
						'value' => 'Esperanza Gomes'
					],
					[
						'icon' => '',
						'item' => 'Date',
						'value' => '04.08.2017'
					]
				],
				'fields' => [
					[
						'name' => 'icon',
						'label' => __( 'Icon', 'wythe-elements' ),
						'type' => Controls_Manager::ICON,
						'default' => 'fa fa-wordpress',
					],
					[
						'name' => 'item',
						'label' => __( 'Enter item', 'wythe-elements' ),
						'type' => Controls_Manager::TEXT,
						'default' => ''
					],
					[
						'name' => 'value',
						'label' => __( 'Enter value', 'wythe-elements' ),
						'type' => Controls_Manager::TEXT,
						'default' => ''
					],
					
				],
				'title_field' => '<i class="{{ icon }}"></i> {{ item }} - {{ value }}',
			]
		);

		$this->add_control(
			'list_layout',
			[
				'label' => __( 'List layout', 'wythe-elements' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'items-inline',
				'options' => [
					'items-inline' => __( 'Items inline', 'wythe-elements' ),
					'items-block' => __( 'Items block', 'wythe-elements' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_social_style',
			[
				'label' => __( 'Info list style', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'list_item_color',
			[
				'label' => __( 'Item Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-info-list li:not(.title)' => 'color: {{ VALUE }};',
				],
			]
		);

		$this->add_control(
			'list_value_color',
			[
				'label' => __( 'Value Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-info-list li strong' => 'color: {{ VALUE }};',
					'{{WRAPPER}} .project-info-list li.title' => 'color: {{ VALUE }};',
					'{{WRAPPER}} .project-info-list li i' => 'color: {{ VALUE }};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'asw_title_typography',
				'selector' => '{{WRAPPER}} .project-info-list li.title, {{WRAPPER}} .project-info-list li strong',
			]
		);
		
		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Text Alignment', 'wythe-elements' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'wythe-elements' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'wythe-elements' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'wythe-elements' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .project-info-list' => 'text-align: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();

	}

	/**
	 * Render social icons widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		global $post;
		?>
		<ul class="project-info-list <?php echo esc_attr($settings['list_layout']); ?>" data-scrolled-into-view>
			<?php
				$out = '';
				if( !empty($settings['title']) ) {
					$out.='<li class="title">'.esc_html( $settings['title'] ).'</li>';
				}
				foreach ( $settings['project_info_list'] as $index => $item ) {
					$out .= '<li>';
					if(!empty($item['icon'])) 
						$out .= '<i class="'.$item['icon'].'"></i>';
					if(!empty($item['item']))
						$out .= esc_html($item['item']);
					$out .= '<span class="sep"></span>';
					if(!empty($item['value']))
						$out .='<strong>'.esc_html($item['value']).'</strong>';
					$out .='</li>';
				} 
				if(function_exists('getPostLikeCount')) { $out .= '<li>'.getPostLikeCount(get_the_ID()).'</li>'; }
				echo $out;
			?>
		</ul>
		<?php
	}
}
