<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_service_block extends Widget_Base {
	public function get_name() {
		return 'asw-service-block';
	}
	public function get_title() {
		return __( 'Service block', 'wythe-elements' );
	}
	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-icon-box';
	}
	public function get_categories() {
		return [ 'asw-elements' ];
	}
	protected function _register_controls() {
		$this->start_controls_section(
			'section_asw_title',
			[
				'label' => esc_html__( 'Service Block', 'wythe-elements' ),
			]
		);
		
		$this->add_control(
			'asw_title',
			[
				'label' => __( 'Service Title', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Your title', 'wythe-elements'),
				'title' => __( 'Enter your title text', 'wythe-elements' ),
			]
		);
		$this->add_control(
		'show_icon',
			[
				'label' => __( 'Show icon', 'wythe-elements' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'false',
				'label_on' => __( 'Show', 'wythe-elements' ),
				'label_off' => __( 'Hide', 'wythe-elements' ),
				'return_value' => 'true',
			]
		);
		$this->add_control(
			'asw_icon',
			[
				'label' => __( 'Choose Service Icon', 'wythe-elements' ),
				'type' => Controls_Manager::ICON,
				'default' => 'fa fa-info',
				'condition' => [
					'show_icon' => 'true',
				],
			]
		);

		$this->add_control(
			'asw_text',
			[
				'label' => __( 'Service Block Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your text', 'wythe-elements' ),
				'default' => 'Morbi accumsan ipsum velit. Nam nec tellus a odio tincidunt auctor a ornare odio. Sed non mauris vitae erat conequat ator eu in elit. Class aptent taciti sociosqu ad litora torquent pero conubia nostra, per inceptos himenaeos auris erat justo.',
			]
		);

		$this->add_control(
			'asw_link',
			[
				'label' => __( 'Service Title Link', 'wythe-elements' ),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://google.com',
				'default' => [
					'url' => '',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_asw_title_style',
			[
				'label' => __( 'Service Block', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'asw_title_color',
			[
				'label' => __( 'Service Title Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block .service-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'asw_title_typography',
				'selector' => '{{WRAPPER}} .service-block .service-title',
			]
		);

		$this->add_control(
			'asw_icon_color',
			[
				'label' => __( 'Service Icon Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block .icon-box' => 'color: {{VALUE}};',
				],
				'condition' => [
					'show_icon' => 'true',
				],
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Text Alignment', 'wythe-elements' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'wythe-elements' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'wythe-elements' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'wythe-elements' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .service-block' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_asw_text_style',
			[
				'label' => __( 'Service text', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'asw_text_color',
			[
				'label' => __( 'Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block .text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'asw_text_typography',
				'selector' => '{{WRAPPER}} .service-block .text',
			]
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$asw_text = ! empty( $settings['asw_text'] ) ? $settings['asw_text'] : '';
		$asw_icon = ! empty( $settings['asw_icon'] ) ? '<div class="icon-box"><i class="'.$settings['asw_icon'].'"></i></div>' : '';

		if ( ! empty( $settings['asw_link']['url'] ) ) {
			$this->add_render_attribute( 'url', 'href', $settings['asw_link']['url'] );

			if ( $settings['asw_link']['is_external'] ) {
				$this->add_render_attribute( 'url', 'target', '_blank' );
			}

			if ( ! empty( $settings['asw_link']['nofollow'] ) ) {
				$this->add_render_attribute( 'url', 'rel', 'nofollow' );
			}

			$asw_title = sprintf( '<h4 class="service-title"><a %1$s>%2$s</a></h4>', $this->get_render_attribute_string( 'url' ), esc_html($asw_text));
		} else {
			$asw_title = ! empty( $settings['asw_title'] ) ? '<h4 class="service-title">'.esc_html($settings['asw_title']).'</h4>' : '';
		}

		?>
		
		<div class="service-block"><!-- start service item -->
			<?php if( $settings['show_icon'] == 'true' ) echo $asw_icon; ?><!-- services icon -->
			<?php echo $asw_title;?><!-- services title -->
			<div class="text"><!-- start service text -->
				<?php echo esc_html($asw_text);?>
			</div><!-- end service text -->
		</div><!-- end service item -->
	<?php }
	protected function content_template() {}
}
?>