<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Icon List Widget
 */
class Widget_ASW_team extends Widget_Base {

	/**
	 * Retrieve icon list widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'asw-team';
	}

	/**
	 * Retrieve icon list widget title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team member', 'wythe-elements' );
	}

	/**
	 * Retrieve icon list widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-address-card-o';
	}

	/**
	 * Retrieve the list of categories the icon list widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'asw-elements' ];
	}

	/**
	 * Register icon list widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'asw_section_team',
			[
				'label' => __( 'Team member', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'name',
			[
				'label' => __( 'Member name', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => ''
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Member photo', 'wythe-elements' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'position',
			[
				'label' => __( 'Member position', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => ''
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_social_icon',
			[
				'label' => __( 'Social Icons', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'social_icon_list',
			[
				'label' => __( 'Social Icons', 'wythe-elements' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'social' => 'fa fa-twitter',
						'link' => ['url' => 'http://twitter.com']
					],
					[
						'social' => 'fa fa-dribbble',
						'link' => ['url' => 'http://dribbble.com']
					],
					[
						'social' => 'fa fa-instagram',
						'link' => ['url' => 'http://instagram.com']
					],
				],
				'fields' => [
					[
						'name' => 'social',
						'label' => __( 'Icon', 'wythe-elements' ),
						'type' => Controls_Manager::ICON,
						'label_block' => true,
						'default' => 'fa fa-facebook',
						'include' => [
							'fa fa-apple',
							'fa fa-behance',
							'fa fa-bitbucket',
							'fa fa-codepen',
							'fa fa-delicious',
							'fa fa-digg',
							'fa fa-dribbble',
							'fa fa-envelope',
							'fa fa-facebook',
							'fa fa-flickr',
							'fa fa-foursquare',
							'fa fa-github',
							'fa fa-google-plus',
							'fa fa-houzz',
							'fa fa-instagram',
							'fa fa-jsfiddle',
							'fa fa-linkedin',
							'fa fa-medium',
							'fa fa-pinterest',
							'fa fa-product-hunt',
							'fa fa-reddit',
							'fa fa-shopping-cart',
							'fa fa-slideshare',
							'fa fa-snapchat',
							'fa fa-soundcloud',
							'fa fa-spotify',
							'fa fa-stack-overflow',
							'fa fa-tripadvisor',
							'fa fa-tumblr',
							'fa fa-twitch',
							'fa fa-twitter',
							'fa fa-vimeo',
							'fa fa-vk',
							'fa fa-weibo',
							'fa fa-weixin',
							'fa fa-whatsapp',
							'fa fa-wordpress',
							'fa fa-xing',
							'fa fa-yelp',
							'fa fa-youtube',
						],
					],
					[
						'name' => 'link',
						'label' => __( 'Link', 'wythe-elements' ),
						'type' => Controls_Manager::URL,
						'label_block' => true,
						'default' => [
							'is_external' => 'true',
						],
						'placeholder' => __( 'http://your-link.com', 'wythe-elements' ),
					],
				],
				'title_field' => '<i class="{{ social }}"></i> {{{ social.replace( \'fa fa-\', \'\' ).replace( \'-\', \' \' ).replace( /\b\w/g, function( letter ){ return letter.toUpperCase() } ) }}}',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render icon list widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		?>
		<?php
			$img_url = !empty($settings['image']['url']) ? $settings['image']['url'] : '';
			$member_name = ! empty($settings['name']) ? $settings['name'] : 'Enter name';
			$member_position = ! empty($settings['position']) ? $settings['position'] : 'Enter position';
		?>
		<div class="team-member">
			<div class="member-info">
					<div class="dtable">
						<div class="dtcell">
							<h3 class="member-name"><span><?php echo esc_html( $member_name ); ?></span></h3><!-- team member name -->
							<span class="member-position"><span><?php echo esc_html( $member_position ); ?></span></span><!-- team member position -->
							<ul class="member-socials"><!-- start member social icons -->
							<?php foreach ( $settings['social_icon_list'] as $index => $item ) {
								$social_icon = ! empty( $item['social'] ) ? $item['social'] : '';
								if ( ! empty( $item['link']['url'] ) ) {
									$link_key = 'link_' . $index;

									$this->add_render_attribute( $link_key, 'href', $item['link']['url'] );

									if ( $item['link']['is_external'] ) {
										$this->add_render_attribute( $link_key, 'target', '_blank' );
									}

									if ( $item['link']['nofollow'] ) {
										$this->add_render_attribute( $link_key, 'rel', 'nofollow' );
									}
									echo '<li><a ' . $this->get_render_attribute_string( $link_key ) . '><i class="'.$social_icon.'"></i></a></li>';
								}
							} ?>
							</ul><!-- end member social icons -->
						</div><!-- end div .dtcell -->
					</div><!-- end div .dttable -->
				</div><!-- end div .member-info -->
			<figure class="member-img"><img src="<?php echo esc_url($img_url); ?>" alt="member 1"></figure>
		</div>
		<?php
	}
}
