<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_testimonials extends Widget_Base {
	public function get_name() {
		return 'asw-testimonials';
	}

	public function get_title() {
		return __( 'Testimonials', 'wythe-elements' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'fa fa-comments-o';
	}

	public function get_script_depends() {
		return [ 'owl.carousel' ];
	}

	public function get_categories() {
		return [ 'asw-elements' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_testimonials_custom',
			[
				'label' => esc_html__( 'Testimonials', 'wythe-elements' ),
			]
		);
		
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Number of Items', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => '5',
			]
		);
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_testimonials_style',
			[
				'label' => __( 'Testimonials style', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'testimonials_color',
			[
				'label' => __( 'Text Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials .testimonials-item' => 'color: {{VALUE}};',
					'{{WRAPPER}} .testimonials .owl-nav div' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'testimonials_typography',
				'selector' => '{{WRAPPER}} .testimonials .testimonials-item',
			]
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$post_count = ! empty( $settings['posts_per_page'] ) ? (int)$settings['posts_per_page'] : 5;
		?>
		<div class="testimonials">
			<?php
			$args = array( 
				'posts_per_page' => $post_count,
				'post_type' => 'testi' 
			);
			$recent_posts = wp_get_recent_posts( $args );
			foreach( $recent_posts as $recent ){
				echo '<div class="testimonials-item">' .esc_html( $recent["post_content"] ). '</div>';
			}
			wp_reset_query();
			?>
		</div>

		<?php
	}
}
?>