<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_title extends Widget_Base {
	public function get_name() {
		return 'asw-title';
	}
	public function get_title() {
		return __( 'Title', 'wythe-elements' );
	}
	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-type-tool';
	}
	public function get_categories() {
		return [ 'asw-elements' ];
	}
	protected function _register_controls() {
		$this->start_controls_section(
			'section_asw_title',
			[
				'label' => esc_html__( 'Title', 'wythe-elements' ),
			]
		);
		
		$this->add_control(
			'asw_title',
			[
				'label' => __( 'Title Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Your title', 'wythe-elements'),
				'title' => __( 'Enter your title text', 'wythe-elements' ),
			]
		);
		$this->add_control(
			'asw_subtitle',
			[
				'label' => __( 'Subtitle Text', 'wythe-elements' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Your subtitle', 'wythe-elements'),
				'title' => __( 'Enter your subtitle text', 'wythe-elements' ),
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __( 'View', 'wythe-elements' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_asw_title_style',
			[
				'label' => __( 'Title block', 'wythe-elements' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'asw_title_color',
			[
				'label' => __( 'Title Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .title-block h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'asw_title_typography',
				'selector' => '{{WRAPPER}} .title-block h2',
			]
		);
		$this->add_control(
			'asw_subtitle_color',
			[
				'label' => __( 'Subitle Color', 'wythe-elements' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .title-block .subtitle' => 'color: {{VALUE}};',
				],
				'separator' => 'before'
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'asw_subtitle_typography',
				'selector' => '{{WRAPPER}} .title-block .subtitle',
			]
		);

		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();
		// get our input from the widget settings.
		$asw_title = ! empty( $settings['asw_title'] ) ? '<h2>'.esc_html($settings['asw_title']).'</h2>' : '';
		$asw_subtitle = ! empty( $settings['asw_subtitle'] ) ? '<span class="subtitle">'.esc_html($settings['asw_subtitle']).'</span>' : '';
		?>

		<div class="title-block"><!-- start title block -->
			<?php echo $asw_subtitle; ?>
			<?php echo $asw_title; ?>
		</div>

		<?php
	}
	protected function content_template() {}
}
?>