<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
class Widget_ASW_video extends Widget_Base {
	public function get_name() {
		return 'asw-video';
	}
	public function get_title() {
		return __( 'Video', 'wythe-elements' );
	}
	public function get_icon() {
		return 'fa fa-video-camera';
	}
	public function get_categories() {
		return [ 'asw-elements' ];
	}
	protected function _register_controls() {
		$this->start_controls_section(
			'section_asw_video',
			[
				'label' => esc_html__( 'Video Block', 'wythe-elements' ),
			]
		);
		$this->add_control(
			'video_formats',
			[
				'label' => __( 'Video formats', 'wythe-elements' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'url' => '',
						'format' => 'mp4'
					],
					[
						'url' => '',
						'format' => 'webm'
					]
				],
				'fields' => [
					[
						'name' => 'url',
						'label' => __( 'Link to video file', 'wythe-elements' ),
						'type' => Controls_Manager::TEXT,
						'default' => '',
						'placeholder' => __( 'http://your-video.mp4', 'wythe-elements' ),
					],
					[
						'name' => 'format',
						'label' => __( 'Select video format', 'wythe-elements' ),
						'type' => Controls_Manager::SELECT,
						'default' => 'mp4',
						'options' => [
							'mp4' => __( 'MP4', 'wythe-elements' ),
							'webm' => __( 'WebM', 'wythe-elements' ),
							'mov' => __( 'MOV', 'wythe-elements' ),
							'ogg' => __( 'Ogg', 'wythe-elements' ),
						],
					],
					
				],
				'title_field' => '{{ url }} {{ format }}',
			]
		);
		$this->add_control(
			'placeholder',
			[
				'label' => __( 'Placeholder image', 'wythe-elements' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'height',
			[
				'label' => __( 'Height (px)', 'wythe-elements' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 675,
				],
				'range' => [
					'px' => [
						'max' => 900,
						'min' => 100,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .video video' => 'height: {{SIZE}}px;',
				],
			]
		);
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings();
		$out = '<div class="video">
					<video width="100%" height="'.esc_attr($settings['height']['size']).'px" poster="'.esc_html( $settings['placeholder']['url'] ).'">';
					foreach ( $settings['video_formats'] as $index => $item ) {
						$out .= '<source src="'.esc_html($item['url']).'" type="video/'.esc_attr($item['format']).'">';
					}
					$out .= 'Your browser does not support the video tag.
					</video>
					<a href="#" class="video-play"><i class="fa fa-play"></i></a>
				</div>';
		echo $out;
	}
	protected function content_template() {}
}
?>